@@ -30,7 +30,7 @@
 @file      query.hpp
 @brief     Query engine and UI
 @author    Robert van Engelen - engelen@genivia.com
-@copyright (c) 2019-2020, Robert van Engelen, Genivia Inc. All rights reserved.
+@copyright (c) 2019-2022, Robert van Engelen, Genivia Inc. All rights reserved.
 @copyright (c) BSD-3 License - see LICENSE.txt
 */
 
@@ -112,6 +112,8 @@ class Query {
 
     bool restore(Line& line_, int& col_, int& row_, Flags flags_[])
     {
+      row_ = 0;
+
       if (row < 0)
         return false;
 
@@ -176,7 +178,7 @@ class Query {
 
   static void draw();
 
-  static void view(int row);
+  static void disp(int row);
 
   static void redraw();
 
@@ -307,6 +309,7 @@ class Query {
   static char                     searching_[16];
   static int                      dots_;
   static size_t                   context_;
+  static size_t                   only_context_;
   static size_t                   fuzzy_;
   static bool                     dotall_;
 
